import React, { useState, useCallback } from 'react';
import { Button, Spin, Upload, notification } from 'antd';
import { UploadOutlined } from '@ant-design/icons';
import ReactPlayer from 'react-player/lazy';
import uploadFile from '@/utils/uploadFile';

import Styles from './style.less';

export default (props) => {
  const [loading, setLoading] = useState(false);

  const handleChange = useCallback(
    ({ file }) => {
      switch (file.status) {
        case 'done':
          setLoading(false);
          props.onChange(file.response);
          break;
        case 'error':
          setLoading(false);
          notification.error({ message: file.error });
          break;
        default:
          setLoading(true);
      }
    },
    [props],
  );

  return (
    <div className={Styles['player-wrapper']}>
      <div className={Styles['upload-btn']}>
        <Upload maxCount={1} customRequest={uploadFile} onChange={handleChange}>
          <Button icon={<UploadOutlined />}>上传视频</Button>
        </Upload>
      </div>
      <Spin spinning={loading}>
        <div className={Styles['react-player']}>
          <ReactPlayer controls muted url={props.value} width="100%" height="100%" />
        </div>
      </Spin>
    </div>
  );
};
