import React, { useState, useRef } from 'react';
import { Alert, Button, message, Space, Modal, Table } from 'antd';
import { FileExcelOutlined, SaveOutlined, RedoOutlined } from '@ant-design/icons';
import { saveTestExcel } from '@/services/test';
import Step from './components/Step'
import { read } from './excel'

const fullWidth = { width: '100%' }

export default (props) => {
  const { schoolId } = props

  const [visible, setVisible] = useState(false)
  const [reading, setReading] = useState(false)
  const [submitting, setSubmitting] = useState(false)

  const workbookRef = useRef()
  const [dataSource, setDataSource] = useState([])

  const columns = [
    {
      key: 'index',
      title: '序号',
      width: 200,
      align: 'center',
      render: (t,r,i) => i + 1,
    },
    {
      key: 'testNo',
      dataIndex: 'testNo',
      title: '体检号',
      align: 'center',
    },
    {
      key: 'studentNo',
      dataIndex: 'studentNo',
      title: '学号',
      align: 'center',
    },
  ]

  const handleFile = () => {
    const input = document.createElement('input')
    input.type = 'file'
    input.accept = 'application/vnd.ms-excel,application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
    input.onchange = (e) => {
      const file = e.target.files[0]
      if (!file) {
        message.warning('请选择文件')
      }

      setReading(true)
      read(file).then((res) => {
        workbookRef.current = res
        setReading(false)
        setVisible(true)
      }).catch((err) => {
        console.error(err)
        setReading(false)
      })
    }
    input.click()
  }
  

  const handleSettingChange = (e) => {
    setVisible(false)

    const { dataStartRow, sheet, cols } = e

    const [, end] = sheet['!ref'].split(':')
    const maxRow = /\d+/.exec(end)[0] - 0
    const arr = []
    for (let i = dataStartRow; i <= maxRow; i += 1) {
      const testNo = sheet[`${cols.testNoCol}${i}`]?.v
      const studentNo = sheet[`${cols.studentNoCol}${i}`]?.v

      arr.push({
        testNo,
        studentNo,
        schoolId,
      })
    }

    setDataSource(arr)
  }
  
  const handleSubmit = () => {
    setSubmitting(true)
    saveTestExcel(dataSource).then(() => {
      setSubmitting(false)
      setDataSource([])
      message.success("保存入库成功");
    }).catch((err) => {
      console.error(err);
      message.error(err.message);
      setSubmitting(false)
    })
  }

  return (
    <div>
      <Space direction="vertical" size="large" style={fullWidth}>
        <Alert description="Excel 文件数据不要超过 200 列, 2000 行。如果出现未知错误, 请退出重试几次" type="warning" closable />
        <Space direction="horizontal" size="large" style={fullWidth}>
          <Button
            ghost
            type="primary"
            loading={reading}
            disabled={!schoolId}
            icon={<FileExcelOutlined />}
            onClick={handleFile}
          >上传 Excel 文件</Button>

          <Button
            ghost
            type="primary"
            disabled={!dataSource.length}
            icon={<RedoOutlined />}
            onClick={() => setDataSource([])}
          >重置</Button>
          
          <Button
            type="primary"
            loading={submitting}
            disabled={!dataSource.length}
            icon={<SaveOutlined />}
            onClick={handleSubmit}
          >保存入库</Button>
        </Space>
        <Table columns={columns} dataSource={dataSource} rowKey="testNo" pagination={false} />
      </Space>
      <Modal
        title="设置数据内容"
        visible={visible}
        onCancel={() => setVisible(false)}
        footer={null}
        width={480}
        maskClosable={false}
      >
        <Step workbook={workbookRef.current} onChange={handleSettingChange} />
      </Modal>
    </div>
  )
}
