import React, { useState } from 'react';
import { Button, Space, Table, Progress, message } from 'antd';
import { FileZipOutlined, SaveOutlined, RedoOutlined } from '@ant-design/icons';
import { uploadPdf } from '@/utils/uploadFile';
import { saveTestPDF } from '@/services/test';

const fullWidth = { width: '100%' }

const getFileName = (url) => {
  const parts = url.split('/');
  return parts[parts.length - 1];
}

export default (props) => {
  const { schoolId } = props
  
  const [loading, setLoading] = useState(false)
  const [submitting, setSubmitting] = useState(false)
  const [percent, setPercent] = useState(0)
  const [dataSource, setDataSource] = useState([])

  const columns = [
    {
      key: 'index',
      title: '序号',
      width: 200,
      align: 'center',
      render: (t,r,i) => i + 1,
    },
    {
      key: 'studentName',
      dataIndex: 'studentName',
      title: '姓名',
      align: 'center',
    },
    {
      key: 'testNo',
      dataIndex: 'testNo',
      title: '体检编号',
      align: 'center',
    },
    {
      key: 'fileName',
      dataIndex: 'fileName',
      title: '文件',
      align: 'center',
      render: (t, r) => <a href={r.url}>{t}</a>
    },
  ];

  const handleFile = () => {
    const input = document.createElement('input')
    input.type = 'file'
    input.accept = 'application/pdf'
    input.multiple = true
    input.onchange = (e) => {
      const { files } = e.target
      if (!files || !files.length) {
        message.warning('请选择文件')
      }

      const len = files.length;
      const list = [];

      let i = 0;
      let j = 0;
      setLoading(true);
      setPercent(0);
      const t = setInterval(() => {
        if (i >= len) {
          clearInterval(t);
          const newLst = list.map((url) => {
            const fileName = getFileName(url)
            const testNo = /^[^-]+/.exec(fileName)[0]
            const studentName = /-(.+)\.pdf/.exec(fileName)[1]

            return {
              schoolId,
              testNo,
              studentName: decodeURIComponent(studentName),
              fileName: decodeURIComponent(fileName),
              url,
            }
          })

          setDataSource([...dataSource, ...newLst])
          setLoading(false)
          return;
        }

        uploadPdf(files[i]).then((url) => {
          j += 1;
          setPercent(j * 100 / len)
          list.push(url);
        }).catch((err) => {
          clearInterval(t);
          console.error(err);
          message.error(err.message);
        })
        i += 1;
      }, 500);
    }
    input.click()
  }

  const handleSubmit = () => {
    setSubmitting(true)
    saveTestPDF(dataSource).then(() => {
      setSubmitting(false)
      setDataSource([])
      message.success("保存入库成功");
    }).catch((err) => {
      console.error(err);
      message.error(err.message);
      setSubmitting(false)
    })
  }

  return (
    <Space direction="vertical" size="large" style={fullWidth}>
      <Space direction="horizontal" size="large" style={fullWidth}>
        <Button
          ghost
          type="primary"
          loading={loading}
          disabled={!schoolId}
          icon={<FileZipOutlined />}
          onClick={handleFile}
        >上传 PDF 文件</Button>

        <Button
          ghost
          type="primary"
          disabled={!dataSource.length}
          icon={<RedoOutlined />}
          onClick={() => setDataSource([])}
        >重置</Button>
        
        <Button
          type="primary"
          loading={submitting}
          disabled={!dataSource.length}
          icon={<SaveOutlined />}
          onClick={handleSubmit}
        >保存入库</Button>

        {
          loading && <Progress style={{width: '400px'}} percent={percent} showInfo={false}/>
        }
      </Space>
      <Table columns={columns} dataSource={dataSource} rowKey="testNo" pagination={false} />
    </Space>
  )
}
