import React, { useState, useRef } from 'react'
import { Row, Col, Button, InputNumber, Select, Carousel, Typography } from 'antd'
import { getRangeOfSheet, getAllCols } from '../excel'
import styles from './style.less'

const { Title } = Typography;
const { Option } = Select;

const ColSelect = (props) => {
  const { value, onChange, cols } = props

  return (
    <Select value={value} onChange={onChange} allowClear style={{minWidth: '90%'}}>
      {
        cols.map((col) => (<Option key={col} value={col}>{col}</Option>))
      }
    </Select>
  )
}

export default (props) => {
  const { workbook, onChange } = props

  const sliderRef = useRef()
  const [sheetName, setSheetName] = useState()
  const sheetRef = useRef()
  const [allCols, setAllCols] = useState([])
  const [studentNoCol, setStudentCol] = useState()
  const [testNoCol, setTestCol] = useState()
  const [dataStartRow, setDataStartRow] = useState(2)

  const maped = studentNoCol && testNoCol && studentNoCol !== testNoCol

  const handleSheetSelect = (nm) => {
    setSheetName(nm)
    sheetRef.current = workbook.Sheets[nm]

    const sheetRange = getRangeOfSheet(sheetRef.current)
    const cols = getAllCols(sheetRange.startCol, sheetRange.endCol)
    setAllCols(cols)
  }

  const next = () => {
    sliderRef.current.next()
  }

  const handleSubmit = () => {
    onChange({
      sheet: sheetRef.current,
      cols: { studentNoCol, testNoCol },
      dataStartRow,
    })
    
    const t = setTimeout(() => {
      // 重置所有
      sliderRef.current.goTo(0, true)
      setSheetName()
      sheetRef.current = null
      setAllCols([])
      setStudentCol()
      setTestCol()
      setDataStartRow(2)
      clearTimeout(t)
    })
  }

  return (
    <div>
      <Carousel ref={sliderRef} style={{width: '100%'}}>
        {/* 第一步 */}
        <div className={styles['step-box']}>
            <Title level={5}>请选择 sheet</Title>
            <div className={styles['step-content']}>
              <Select value={sheetName} onChange={handleSheetSelect}  style={{minWidth: '200px'}}>
                {
                  (workbook.SheetNames || []).map((nm) => (<Option key={nm} value={nm}>{nm}</Option>))
                }
              </Select>
            </div>
            <Button disabled={!sheetName} type="primary" onClick={next}>下一步</Button>
        </div>
        
        {/* 第二步 */}
        <div className={styles['step-box']}>
          <Title level={5}>请设置 数据映射列</Title>
          <div className={styles['step-content']}>
            <Row style={{padding: '.3em 0'}}>
              <Col span={12}>体检号:</Col>
              <Col span={12}><ColSelect cols={allCols} value={testNoCol} onChange={setTestCol} /></Col>
            </Row>
            <Row style={{padding: '.3em 0'}}>
              <Col span={12}>学号:</Col>
              <Col span={12}><ColSelect cols={allCols} value={studentNoCol} onChange={setStudentCol} /></Col>
            </Row>
          </div>
          <Button type="primary" disabled={!maped} onClick={next}>下一步</Button>
        </div>
        
        {/* 第三步 */}
        <div className={styles['step-box']}>
          <Title level={5}>请设置 数据起始行</Title>
          <div className={styles['step-content']}>
            <InputNumber value={dataStartRow} onChange={setDataStartRow} step={1} min={1} max={1000} />
          </div>
          <Button type="primary" disabled={!dataStartRow} onClick={handleSubmit}>完成</Button>
        </div>
      </Carousel>
    </div>
  )
}
