import React, { useState, useRef, useCallback } from 'react';
import { connect, history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import { PlusOutlined, GroupOutlined } from '@ant-design/icons';
import { Button,  Space, Popconfirm, message } from 'antd';
import  { queryTable } from '@/utils/request';
import School from '@/components/School';
import Specialty from '@/components/Specialty';
import { deleteTestLog } from '@/services/test';

const VisitList = () => {

  const [school, setSchool] = useState({});  
  const ref = useRef();
  const actionRef = useRef();

  const handleMedicalClick = useCallback((id) => {
    history.push(id ? `/medical/Test/edit?id=${id}&schoolId=${school?.schoolId}` : `/medical/Test/edit?schoolId=${school?.schoolId}`);
  }, []);

  const handleBatch = () => {
    history.push('/medical/Test/batch')
  }

  const handleConfirm = (item) => {
    deleteTestLog(item.serialNo).then(() => {
      actionRef.current.reload()
      message.success("删除成功")
    }).catch(() => {
      message.error("操作失败, 请重试")
    })
  }

  const actions = [
    <Button key="batch" icon={<GroupOutlined />} type="primary" ghost onClick={handleBatch}>
      批量处理
    </Button>,
    <Button key="new" icon={<PlusOutlined />} type="primary" onClick={() => handleMedicalClick()}>
      新建
    </Button>,
  ];

  const columns = [
    {
      title: '编号',
      dataIndex: 'serialNo',
      hideInSearch: true,

      align: 'center',
    },
    {
      title: '学校',
      dataIndex: 'schoolId',
      align: 'center',
      render: (_, row) => row.schoolName||"-",
      renderFormItem: (item, config, form) => (
        <School
          autoDefault={false}
          value={school?.schoolId}
          onChange={(schoolId, v) => {
            setSchool(v)
            form.setFieldsValue({ schoolId, specialtyId: null })
          }}
          allowClear
        ></School>
      ),
    },
    {
      title: '专业',
      dataIndex: 'specialtyId',
      align: 'center',
      render: (_, row) => row.specialtyName||'-',
      renderFormItem: (item, config, form) => {
        return <Specialty schoolId={school?.schoolId} disabled={!school?.schoolId}></Specialty>;
      },
    },
    {
      title: '学号',
      dataIndex: 'studentNo',
      align: 'center',
    },
    {
      title: '体检编号',
      dataIndex: 'testNo',
      align: 'center',
    },
    {
      title: '姓名',
      dataIndex: 'name',
      align: 'center',
      hideInSearch: true,
      // hideInTable: true,
    },
    {
      title: '性别',
      dataIndex: 'sex',
      align: 'center',
      hideInSearch: true,
      valueEnum: {
        1: { text: '男' },
        2: { text: '女' },
      },
    },
    {
      title: '创建时间',
      dataIndex: 'createDate',
      align: 'center',
      hideInSearch: true,
      valueType: 'dateTime',
    },
    
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      hideInSearch: true,
      render: (text, record) => (
        <Space size="middle">
          <a href={record.attchment} target="_blank" rel="noreferrer">查看报告</a>
          {/* <a onClick={()=>setA(record.attchment)}>查看报告</a> */}
          <Popconfirm
            title="确认删除数据?"
            onConfirm={() => handleConfirm(record)}
          ><a href="#">删除</a></Popconfirm>
        </Space>
      ),
    },
  ];

  return (
    <PageContainer>
      <ProTable
        columns={columns}
        params={{}}
        request={queryTable('/testLog')}
        formRef={ref}
        rowKey="serialNo"
        headerTitle="体检列表"
        search={{
          labelWidth: '4em',
        }}
        toolBarRender={() => actions}
        actionRef={actionRef}
      />
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(VisitList);
