import React, { useEffect, useState } from 'react';
import { connect, history } from 'umi';

import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import { Input, Form, Button, notification } from 'antd';
import ProForm, { ProFormText, ProFormTextArea, ProFormSelect } from '@ant-design/pro-form';
import request from '@/utils/request';
import School from '@/components/School';
import Specialty from '@/components/Specialty'

const { Search } = Input;
const VisitEdit = (props) => {
  const { id, schoolId } = props.location.query;

  const [searchLoading, setSearchLoading] = useState(false);
  const [school, setSchool] = useState();
  const [specialtyId, setSpecialtyId] = useState()
  const [searchValue, setSearchValue] = useState();
  
  const [form] = Form.useForm();

  // eslint-disable-next-line no-shadow
  const getData = (id) => {
    if (id) {
      request(`/student-no/${id}`,{params:{schoolId:school}})
        .then((res) => {
          form.setFieldsValue(res);
          setSearchLoading(false);
        })
        .catch((e) => {
          setSearchLoading(false);
          notification.error({ message: '未找到该学生' })
          form.resetFields()
        });
    } else {
      // this.setState({ data: [] });
    }
  };

  useEffect(() => {
    if (id) {
      if (id) {
        request(`/medical-log/${id}`)
          .then((res) => {
            form.setFieldsValue(res);
            setSearchLoading(false);
          })
          .catch((e) => {
            setSearchLoading(false);
          });
      } else {
        // this.setState({ data: [] });
      }
    }
  }, [id]);

  const onSearch = (value) => {
    if (value) {
      getData(value);
      setSearchLoading(true);
    } else {
      // this.setState({ data: [] });
    }
  };

  const handleSubmit = (value) => {
    if (!specialtyId) {
      notification.warn({ message: '请选择专业' })
      return;
    }

    request('/medicalLog', { method: 'post', data: { schoolId: school, specialtyId, ...value } })
      .then(() => {
        notification.success({ message: '新建成功' });
        history.go('-1');
      })
      .catch((e) => {
        notification.error({ message: e.message });
      });
  };

  const handleSchoolChange = (value) => {
    setSchool(value)
    setSearchValue('')
    form.resetFields()
  };

  return (
    <PageContainer
      header={{
        extra: [
          <Button key="1" onClick={() => history.go('-1')}>
            返回
          </Button>,
        ],
      }}
    >
      <Container>
        <ProForm form={form} submitter={!id} onFinish={handleSubmit}>
          {!id && (
            <ProForm.Group layout="inline">
              <School value={school} onChange={handleSchoolChange} style={{ width: 200, marginBottom: '20px' }} allowClear />
              <Search
                placeholder="请输入学号"
                value={searchValue}
                onChange={(e)=>setSearchValue(e.value)}
                loading={searchLoading}
                style={{ width: 200, marginBottom: '20px' }}
                onSearch={onSearch}
              />
            </ProForm.Group>
          )}
          <ProForm.Group layout="inline" title="就诊信息">
            <Form.Item label="专业" required>
              <Specialty
                value={specialtyId}
                schoolId={schoolId || school}
                onChange={(x) => setSpecialtyId(x)}
                style={{ minWidth: '150px' }}
                placeholder="请选择专业"
              />
            </Form.Item>

            <ProFormText
              label="姓名"
              placeholder="输入名称"
              name="name"
              fieldProps={{ bordered: !id, readOnly: !!id }}
              rules={[{ required: true, message: '请填写名称' }]}
            />

            <ProFormSelect
              options={[
                {
                  value: 1,
                  label: '男',
                },
                {
                  value: 2,
                  label: '女',
                },
              ]}
              name="sex"
              label="性别"
              fieldProps={{ bordered: !id, open: id ? false : undefined }}
              rules={[{ required: true, message: '请选择性别' }]}
            />

            <ProFormText
              label="学号"
              placeholder="输入学号"
              name="studentNo"
              fieldProps={{ bordered: !id, readOnly: !!id }}
              rules={[{ required: true, message: '请填写学号' }]}
            />

            <ProFormText
              label="联系方式"
              placeholder="输入联系方式"
              name="phone"
              fieldProps={{ bordered: !id, readOnly: !!id }}
              rules={[{ required: true, message: '请填写联系方式' }]}
            />
          </ProForm.Group>

          <ProFormTextArea
            label="诊断报告"
            placeholder="输入诊断报告"
            name="attchment"
            fieldProps={{ readOnly: !!id, rows: 10 }}
            rules={[{ required: true, message: '请填写诊断报告' }]}
            style={{ width: '100%' }}
          />
        </ProForm>
      </Container>
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(VisitEdit);
