import React, { useEffect, useRef, useState } from 'react';
import { Drawer, Button, Row, Col, Space, notification } from 'antd';
import ProTable from '@ant-design/pro-table';
import request from '@/utils/request';
import TestQuestions from '@/components/TestQuestions';

const answerTypeDict = {
  switch: '判断',
  radio: '单选题',
  checkbox: '多选题',
}

export default (props) => {
  const [visible, setVisible] = useState(false)
  const tableRef = useRef()
  const [ postTest, setPostTest ] = useState({})

  const handleEdit = (item) => {
    setVisible(true)
    setPostTest(item)
  }

  const columns = [
    {
      title: '题型',
      width: 80,
      key: 'answerType',
      dataIndex: 'answerType',
      valueEnum: Object.keys(answerTypeDict).reduce((acc, key) => ({
        ...acc,
        [key]: { text: answerTypeDict[key] }
      }), {}),
    },
    {
      title: '考题',
      key: 'title',
      dataIndex: 'title',
      ellipsis: true,
    },
    {
      title: '选项',
      key: 'optionA',
      dataIndex: 'optionA',
      render: (_, item) => (
        <Space direction="vertical" style={{ width: '100%' }}>
          <Row gutter={24}>
            <Col span={12}>{`A. ${item.optionA}`}</Col>
            <Col span={12}>{`B. ${item.optionB}`}</Col>
          </Row>
          {
            item.answerType !== 'switch' && (
              <Row gutter={24}>
                <Col span={12}>{`C. ${item.optionC}`}</Col>
                <Col span={12}>{`D. ${item.optionD}`}</Col>
              </Row>
            )
          }
        </Space>
      )
    },
    {
      title: '正确答案',
      width: 100,
      key: 'correctAnswers',
      dataIndex: 'correctAnswers',
    },
    {
      title: '操作',
      width: 80,
      key: 'option',
      render: (_, item) => (
        <a onClick={() => handleEdit(item)}>编辑</a>
      )
    },
  ]

  const actions = [
    <Button key="add" type="primary" onClick={() => handleEdit({})}>新增</Button>,
  ]

  const requestMock = () => {
    const postTestList = props.post.postTestList || []
    return Promise.resolve({
      data: postTestList,
      success: true,
      total: postTestList.length,
    })
  }

  const handleSubmit = (value) => {
    const data = {
      ...value,
      postId: props.post.postId,
    }

    if (!data.serialNo) {
      // 新增
      request('/post-test', { method: 'post', data }).then((res) => {
        setVisible(false)
  
        if (props.onChange) {
          const postTestList = props.post.postTestList || []
          props.onChange([res].concat(postTestList))
        }
      }).catch((e) => {
        notification.error({ message: e.message })
      })
    } else {
      //
    }
  }

  useEffect(() => {
    if (tableRef.current) {
      tableRef.current.reload()
    }
  }, [props.post.postTestList])

  return (
    <div>
      <Drawer
        title="试题维护"
        placement="right"
        onClose={() => setVisible(false)}
        visible={visible}
        width={850}
      >
        <TestQuestions value={postTest} answerTypeDict={answerTypeDict} onSubmit={handleSubmit} onCancel={() => setVisible(false)} />
      </Drawer>
      <ProTable
        actionRef={tableRef}
        request={requestMock}
        columns={columns}
        headerTitle="题库"
        rowKey="serialNo"
        search={false}
        toolBarRender={() => actions}
      />
    </div>
  );
};
