import React, { useEffect, useRef, useState } from 'react';
import { connect, history } from 'umi';
import {Space, Button, notification} from 'antd'
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import request, { queryTable } from '@/utils/request';
import DetailDrawer from './components/DetailDrawer'

const StudentData = (props) => {
  // const { postId } = props.location.query;
  const paramRef = useRef();
  const [exporting, setExporting] = useState(false)
  const [student, setStudent] = useState();
  const [modalVisible, setModalVisible] = useState({
    points: false,
    saved: false,
    readed: false,
  })

  const toggleModal = (modal, visible) => {
    setModalVisible({
      ...modalVisible,
      [modal]: visible,
    })
  }

  const tableRef = useRef()
  const [schoolDict, setSchoolDict] = useState({})

  const toSave = (row) =>{
    setStudent(row);
    if(row.savedNum>0){
      toggleModal('saved', true);
    }
  }

  const toReade = (row) =>{
    setStudent(row);
    if(row.readedNum>0){
      toggleModal('readed', true);
    }
  }
  const toPoint = (row) =>{
    setStudent(row);
    if(row.pointNum>0){
      toggleModal('points', true);
    }
  }

  const columns = [
    {
      title: '排名',
      key: 'topN',
      hideInSearch: true,
      render: (_, $, index) => index + 1,
    },
    {
      title: '学校',
      key: 'schoolId',
      dataIndex: 'schoolId',
      valueType: 'select',
      valueEnum: schoolDict,
    },
    {
      title: '名称',
      key: 'name',
      dataIndex: 'name',
    },
    {
      title: '手机号',
      key: 'phone',
      dataIndex: 'phone',
      hideInSearch: true,
    },
    {
      title: '收藏文章数',
      key: 'savedNum',
      dataIndex: 'savedNum',
      hideInSearch: true,
      sorter: true,
      render: (text, row) => (
        <Space size="middle">
          {text?<a onClick={() => toSave(row)}>{text}</a>:0}
        </Space>
      ),
    },
    {
      title: '阅读文章数',
      key: 'readedNum',
      dataIndex: 'readedNum',
      hideInSearch: true,
      sorter: true,
      render: (text, row) => (
        <Space size="middle">
          {text?<a onClick={() => toReade(row)}>{text}</a>:0}
        </Space>
      ),
    },
    {
      title: '总积分',
      key: 'pointNum',
      dataIndex: 'pointNum',
      hideInSearch: true,
      sorter: true,
      render: (text, row) => (
        <Space size="middle">
          {text?<a onClick={() => toPoint(row)}>{text}</a>:0}
        </Space>
      ),
    },
    {
      title: '学分',
      key: 'creditNum',
      dataIndex: 'creditNum',
      hideInSearch: true,
      sorter: true,
    },
  ]

  const handleBeforeSearch = (params) => {
    const paramData = {
      name: params.name,
      schoolId: params.schoolId,
      specialtyId: params.specialtyId,
    }

    // copy 一份
    paramRef.current = paramData
    return params
  }

  const handleExport = () => {
    setExporting(true)
    request('/export/statis/student-data', { params: paramRef.current || {} }).then(() => {
      setExporting(false)
    }).catch((err) => {
      setExporting(false)
      notification.error({ message: err.message })
    })
  }

  useEffect(() => {
    request('/school', { params: { pageSize: 500 } }).then(res => {
      const records = res.records || []
      const dict = records.reduce((acc, item) => {
        return {
          ...acc,
          [item.schoolId]: { text: item.name },
        };
      }, {})
      setSchoolDict(dict)
    }).catch((e) => {
      // eslint-disable-next-line
      console.error(e.message)
    })

  // eslint-disable-next-line
  }, [])

  return (
    <PageContainer
    header={{
      extra: [
        <Button key="1" onClick={() => history.go('-1')}>
          返回
        </Button>,
      ],
    }}>
      <ProTable
        actionRef={tableRef}
        columns={columns}
        beforeSearchSubmit={handleBeforeSearch}
        request={queryTable('/statis/student-data')}
        rowKey="personId"
        search={{ labelWidth: '4em' }}
        toolBarRender={() => [
          <Button key="export" type="primary" loading={exporting} onClick={handleExport}>导出</Button>
        ]}
      />

      <DetailDrawer student={student} visible={modalVisible} onClose={setModalVisible} />
    </PageContainer>
  );
};

export default connect((s) => ({
  user: s.user.currentUser,
}))(StudentData);
