import React, { useCallback, useState } from 'react';
import { history } from 'umi';
import { Space } from 'antd';
import moment from 'moment';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import School from '@/components/School';
import { queryTable } from '@/utils/request';
import Specialty from '@/components/Specialty';

const StudentList = () => {

  const [school, setSchool] = useState({});

  const handleStudentClick = useCallback((id) => {
    if (id) {
      history.push(`/student/student/edit?id=${id}`);
    }
  }, []);

  const columns = [
    // {
    //   title: '编号',
    //   dataIndex: 'studentId',
    //   align: 'center',
    //   width: 300,
    //   hideInSearch: true,
    // },
    {
      title: '姓名',
      dataIndex: 'name',
      align: 'center',
    },
    {
      title: '联系方式',
      dataIndex: 'phone',

      align: 'center',
    },
    {
      title: '学校',
      dataIndex: 'schoolId',
      align: 'center',
      render: (_, row) => row.schoolName||"-",
      renderFormItem: (item, config, form) => (
        <School
          autoDefault={false}
          value={school?.schoolId}
          onChange={(schoolId, v) => {
            setSchool(v)
            form.setFieldsValue({ schoolId, specialtyId: null })
          }}
          allowClear
        ></School>
      ),
    },
    {
      title: '专业',
      dataIndex: 'specialtyId',
      align: 'center',
      render: (_, row) => row.specialtyName||'-',
      renderFormItem: (item, config, form) => {
        return <Specialty schoolId={school?.schoolId} disabled={!school?.schoolId}></Specialty>;
      },
    },
    {
      title: '学号',
      dataIndex: 'studentNo',
      align: 'center',
    },
    {
      title: '注册时间',
      dataIndex: 'createDate',
      align: 'center',
      render: t => moment(t).format('YYYY-MM-DD HH:mm')
    },
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      hideInSearch: true,
      render: (text, record) => (
        <Space size="middle">
          <a onClick={() => handleStudentClick(record.studentId)}>用户详情 </a>
        </Space>
      ),
    },
  ];

  return (
    <PageContainer>
      <ProTable
        columns={columns}
        request={queryTable('/student')}
        rowKey="studentId"
        headerTitle="学生列表"
        search={{ labelWidth: '4em' }}
      />
    </PageContainer>
  );
};

export default StudentList;
